@@ -28,7 +28,7 @@ use constant EPP_XMLNS	=> 'urn:ietf:params:xml:ns:epp-1.0';
 use vars qw($Error $Code $Message);
 
 BEGIN {
-	our $VERSION = '0.07_01';
+	our $VERSION = '0.07_02';
 }
 
 # file-scoped lexicals
@@ -273,6 +273,12 @@ this module only supports two sets: the standard tasks and the tag list.
 sub login {
 	my ($self, $user, $pass, $options) = @_;
 
+	if ($self->{authenticated}) {
+		$Error = 'Already logged in';
+		carp ($Error);
+		return;
+	}
+
 	unless (defined $user) {
 		$Error = 'No username (tagname) supplied';
 		carp ($Error);
@@ -285,6 +291,8 @@ sub login {
 		return;
 	}
 
+	$self->_go_connect () unless $self->{connected};
+
 	# Set login frame
 	my $login = Net::EPP::Frame::Command::Login->new;
 
@@ -339,6 +347,13 @@ sub login {
 	return $self;
 }
 
+sub logout {
+	my $self = shift;
+	my $res = $self->SUPER::logout (@_);
+	$self->{authenticated} = 0 if $res;
+	return $res;
+}
+
 =head1 Availability checks
 
 The availability checks work similarly to L<Net::EPP::Simple> except
@@ -1267,9 +1282,9 @@ contact ID. If this is undef then the existing contact will be that on
 the listed domains.
 
 The second optional argument is the ID of the new contact to create. If
-this is undef then a random ID will be assigned.
+this is undef then a random ID will be assigned by Nominet.
 
-The third and subsequent agruments are the domain names to be moved from the
+The third and subsequent arguments are the domain names to be moved from the
 existing contact to the new.
 
 Returns the new contact ID on success, undef otherwise.
